// MainDlg.h : interface of the CMainDlg class
//
/////////////////////////////////////////////////////////////////////////////

#pragma once
#define WM_DWMCOMPOSITIONCHANGED 0x031E		// WTL does not have this message
#include "dwmapi.h"
#pragma comment(lib,"dwmapi.lib")
#include "GlowingText.h"
#pragma comment(lib,"GlowingText.lib")
#include "atlstr.h"

class CMainDlg : public CDialogImpl<CMainDlg>, public CUpdateUI<CMainDlg>,
		public CMessageFilter, public CIdleHandler
{
private:
	BOOL m_bAeroEnabled;
public:
	enum { IDD = IDD_MAINDLG };

	virtual BOOL PreTranslateMessage(MSG* pMsg)
	{
		return CWindow::IsDialogMessage(pMsg);
	}

	virtual BOOL OnIdle()
	{
		return FALSE;
	}

	BEGIN_UPDATE_UI_MAP(CMainDlg)
	END_UPDATE_UI_MAP()

	BEGIN_MSG_MAP(CMainDlg)
		MESSAGE_HANDLER(WM_INITDIALOG, OnInitDialog)
		MESSAGE_HANDLER(WM_DESTROY, OnDestroy)
// 		COMMAND_ID_HANDLER(ID_APP_ABOUT, OnAppAbout)
// 		COMMAND_ID_HANDLER(IDOK, OnOK)
		COMMAND_ID_HANDLER(IDCANCEL, OnCancel)
		MESSAGE_HANDLER(WM_CTLCOLORDLG, OnCtlColorDlg)
		MESSAGE_HANDLER(WM_DWMCOMPOSITIONCHANGED, OnCompositionChnaged)
		MESSAGE_HANDLER(WM_TIMER, OnTimer)
	END_MSG_MAP()
	/////////////////////////////////// Custom Handler
	LRESULT OnCompositionChnaged(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
	{
		::DwmIsCompositionEnabled(&m_bAeroEnabled);
		if (m_bAeroEnabled) {
			MARGINS m = {-1,-1,-1,-1};
			::DwmExtendFrameIntoClientArea(m_hWnd,&m);
			Invalidate();	// draw black background

		}
		return 0;
	}
// Handler prototypes (uncomment arguments if needed):
//	LRESULT MessageHandler(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
//	LRESULT CommandHandler(WORD /*wNotifyCode*/, WORD /*wID*/, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
//	LRESULT NotifyHandler(int /*idCtrl*/, LPNMHDR /*pnmh*/, BOOL& /*bHandled*/)

	LRESULT OnInitDialog(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
	{
		// center the dialog on the screen
		CenterWindow();

		// set icons
		HICON hIcon = (HICON)::LoadImage(_Module.GetResourceInstance(), MAKEINTRESOURCE(IDR_MAINFRAME), 
			IMAGE_ICON, ::GetSystemMetrics(SM_CXICON), ::GetSystemMetrics(SM_CYICON), LR_DEFAULTCOLOR);
		SetIcon(hIcon, TRUE);
		HICON hIconSmall = (HICON)::LoadImage(_Module.GetResourceInstance(), MAKEINTRESOURCE(IDR_MAINFRAME), 
			IMAGE_ICON, ::GetSystemMetrics(SM_CXSMICON), ::GetSystemMetrics(SM_CYSMICON), LR_DEFAULTCOLOR);
		SetIcon(hIconSmall, FALSE);

		// register object for message filtering and idle updates
		CMessageLoop* pLoop = _Module.GetMessageLoop();
		ATLASSERT(pLoop != NULL);
		pLoop->AddMessageFilter(this);
		pLoop->AddIdleHandler(this);

		UIAddChildWindowContainer(m_hWnd);
		/////////////////////////////////////////// Aero Support
		::DwmIsCompositionEnabled(&m_bAeroEnabled);
		PostMessage(WM_DWMCOMPOSITIONCHANGED);
		SetTimer(11,1000,NULL);		// current time display
		return TRUE;
	}

	LRESULT OnDestroy(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
	{
		// unregister message filtering and idle updates
		CMessageLoop* pLoop = _Module.GetMessageLoop();
		ATLASSERT(pLoop != NULL);
		pLoop->RemoveMessageFilter(this);
		pLoop->RemoveIdleHandler(this);

		return 0;
	}

// 	LRESULT OnAppAbout(WORD /*wNotifyCode*/, WORD /*wID*/, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
// 	{
// 		CAboutDlg dlg;
// 		dlg.DoModal();
// 		return 0;
// 	}
// 
// 	LRESULT OnOK(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
// 	{
// 		// TODO: Add validation code 
// 		CloseDialog(wID);
// 		return 0;
// 	}

	LRESULT OnCancel(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
	{
		CloseDialog(wID);
		return 0;
	}

	void CloseDialog(int nVal)
	{
		DestroyWindow();
		::PostQuitMessage(nVal);
	}
	LRESULT OnCtlColorDlg(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
	{
		if (m_bAeroEnabled) {
			return (LRESULT)::GetStockObject(BLACK_BRUSH);
		} else {
			return (LRESULT)::GetStockObject(GRAY_BRUSH);
		}
	}
	LRESULT OnTimer(UINT /*uMsg*/, WPARAM wParam, LPARAM /*lParam*/, BOOL& /*bHandled*/)
	{
		
		if (11 == wParam) {
			HDC hdc = ::GetDC(m_hWnd);
			SYSTEMTIME time;
			::GetLocalTime(&time);
			CString s;
			s.Format(L"  %d:%d:%d  ",time.wHour,time.wMinute,time.wSecond);
			POINT p = {90,110};
			::DrawGlowingText(hdc,s,L"Բ",40,&p,8,NULL);
			::ReleaseDC(m_hWnd,hdc);
		}
		return 0;
	}
};
